@@ -267,11 +267,14 @@ impl<R: Renderer + 'static> cursive_core::View for MarkupView<R> {
         self.render(constraint)
     }
 
-    fn take_focus(&mut self, direction: cursive_core::direction::Direction) -> bool {
+    fn take_focus(
+        &mut self,
+        direction: cursive_core::direction::Direction,
+    ) -> Result<cursive_core::event::EventResult, cursive_core::view::CannotFocus> {
         self.doc
             .as_mut()
             .map(|doc| doc.link_handler.take_focus(direction))
-            .unwrap_or_default()
+            .unwrap_or(Err(cursive_core::view::CannotFocus))
     }
 
     fn on_event(&mut self, event: cursive_core::event::Event) -> cursive_core::event::EventResult {
@@ -321,7 +324,7 @@ impl<R: Renderer + 'static> cursive_core::View for MarkupView<R> {
         if let Some(doc) = &self.doc {
             doc.link_handler.important_area()
         } else {
-            cursive_core::Rect::from((0, 0))
+            cursive_core::Rect::from_point((0, 0))
         }
     }
 }
@@ -417,9 +420,12 @@ impl LinkHandler {
         self.links.len() - 1
     }
 
-    pub fn take_focus(&mut self, direction: cursive_core::direction::Direction) -> bool {
+    pub fn take_focus(
+        &mut self,
+        direction: cursive_core::direction::Direction,
+    ) -> Result<cursive_core::event::EventResult, cursive_core::view::CannotFocus> {
         if self.links.is_empty() {
-            false
+            Err(cursive_core::view::CannotFocus)
         } else {
             use cursive_core::direction::{Absolute, Direction, Relative};
             let rel = match direction {
@@ -433,7 +439,7 @@ impl LinkHandler {
                 Relative::Front => 0,
                 Relative::Back => self.links.len() - 1,
             };
-            true
+            Ok(cursive_core::event::EventResult::consumed())
         }
     }
 
@@ -511,7 +517,7 @@ impl LinkHandler {
 
     pub fn important_area(&self) -> cursive_core::Rect {
         if self.links.is_empty() {
-            cursive_core::Rect::from((0, 0))
+            cursive_core::Rect::from_point((0, 0))
         } else {
             let link = &self.links[self.focus];
             cursive_core::Rect::from_size(link.position, (link.width, 1))
